Crate git_lfs_filter

Crate git_lfs_filter 

Clean and smudge filters for git-lfs.

See docs/spec.md  “Intercepting Git” for the protocol contract.

Structs

CleanExtension
One pointer extension’s clean side.

Enums

CleanError
CleanOutcome
Result of running the clean filter on a piece of input.
FilterProcessError
SmudgeError
SmudgeOutcome
Result of running the smudge filter on a piece of input.

Functions

clean
Apply the clean filter to input, writing the resulting pointer (or the pass-through bytes) to output.
filter_process
Run the filter-process protocol against input/output (typically stdin/stdout). Returns when git closes its end of the pipe.
smudge
Apply the smudge filter to input, writing the working-tree content (or pass-through bytes) to output.
smudge_with_fetch
Like smudge, but on a missing-object miss invokes fetch to populate the store, then streams the freshly-fetched bytes to output.

Type Aliases

FetchError
Boxed error returned by the on-demand fetch closure passed to smudge_with_fetch / filter_process.